==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudapi/k8s/resource_k8s_wg/main.tf <==
/*
Пример использования
Управления worker groups (рабочики группами, wg) кластера
Ресурс позволяет:
1. Создавать wg
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}


resource "decort_k8s_wg" "wg" {
  #id экземпляра k8s
  #обязательный параметр
  #тип - целое число
  k8s_id = 1234

  #имя worker group
  #обязательный параметр
  #тип - строка
  name = "workers-2"

  #количество worker node для создания
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 1
  num = 2

  #количество cpu для 1 worker node
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 1
  cpu = 1

  #количество RAM для одной worker node в Мбайтах
  #опциональный параметр
  #тип - целое число
  #по-умолчанию - 1024
  ram = 1024

  #тип эмулируемой системы
  #опциональный параметр
  #тип - строка
  chipset = "i440fx"

  #размер загрузочного диска для worker node, в Гбайтах
  #опциональный параметр
  #тип - целое число
  #по - умолчанию - 0
  #если установлен параметр 0, то размер диска будет равен размеру образа
  disk = 10

  #Перечень аргументов для cloud-init для виртуальных машин worker групп
  #опциональный параметр
  #тип - файл с форматом в виде yaml
  #используется при создании и обновлении ресурса
  cloud_init = file("initconfig.tftpl")

}


output "test_wg" {
  value = decort_k8s_wg.wg
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudapi/k8s/resource_k8s_wg/main.tf <==
/*
Пример использования
Управления worker groups (рабочики группами, wg) кластера
Ресурс позволяет:
1. Создавать wg
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}


resource "decort_k8s_wg" "wg" {
  #id экземпляра k8s
  #обязательный параметр
  #тип - целое число
  #используется при создании
  k8s_id = 1234

  #имя worker group
  #обязательный параметр
  #тип - строка
  #используется при создании
  name = "workers-2"

  #количество worker node
  #опциональный параметр
  #тип - целое число
  #по умолчанию - 1
  #используется при создании и обновлении
  #num = 2

  #количество cpu для 1 worker node
  #опциональный параметр
  #тип - целое число
  #по умолчанию - 1
  #используется при создании
  #cpu = 1

  #количество RAM для одной worker node, в МБ
  #опциональный параметр
  #тип - целое число
  #по умолчанию - 1024
  #используется при создании
  #ram = 1024

  #тип эмулируемой системы
  #опциональный параметр
  #тип - строка
  #используется при создании
  #chipset = "i440fx"

  #размер загрузочного диска для worker node, в ГБ
  #опциональный параметр
  #тип - целое число
  #по умолчанию - 0
  #если установлен параметр 0, то размер диска будет равен размеру образа
  #используется при создании
  #disk = 10

  #перечень аргументов для cloud-init для виртуальных машин worker групп
  #опциональный параметр
  #тип - файл с форматом в виде yaml
  #используется при создании и обновлении
  #cloud_init = file("initconfig.tftpl")

}


output "test_wg" {
  value = decort_k8s_wg.wg
}
